<?php

namespace App\Http\Controllers\Admin;

use Alert;
use Crypt;
use App\Http\Controllers\Controller;
use App\Repositories\Admin\MsTujuanSosialKategoriRepository;
use App\Repositories\Admin\MsTujuanSosialRepository;
use Illuminate\Http\Request;

class TujuanSosialController extends Controller
{
    private $tujuansosialRepo;
    private $tujuansosialkategoriRepo;

    public function __construct(
        MsTujuanSosialKategoriRepository $tujuansosialkategoriRepo,
        MsTujuanSosialRepository $tujuansosialRepo
    ) {
        $this->tujuansosialRepo = $tujuansosialRepo;
        $this->tujuansosialkategoriRepo = $tujuansosialkategoriRepo;
    }

    public function index()
    {
        //
        $menu = 'tujuansosial';
        $tujuansosial = $this->tujuansosialRepo->get(['rKategori']);
        $tujuansosialkategori = $this->tujuansosialkategoriRepo->get();
        //dd($tujuansosialkategori);
        $data = [
            'tujuansosial' => $tujuansosial,
            'tujuansosialkategori' => $tujuansosialkategori,
            'menu' => $menu
        ];

        return view('admin.tujuan.index', $data);
    }

    public function tujuankategori()
    {
        //
        $menu = 'tujuansosial';
        $tujuansosialkategori = $this->tujuansosialkategoriRepo->get();
        //dd($tujuansosialkategori);
        $data = [
            'tujuansosialkategori' => $tujuansosialkategori,
            'menu' => $menu
        ];

        return view('admin.tujuan.kategori', $data);
    }


    public function create()
    {
        //
        return view('admin.tujuan.create');
    }


    public function store(Request $request)
    {
        //
        $data = $request->except('_token');
        $data['user_id'] = auth()->user()->id;
        $tujuansosial = $this->tujuansosialRepo->store($data);

        $data = [
            'tujuansosial' => $tujuansosial->id,
        ];

        Alert::success('Berhasil', 'tujuansosial berhasil disimpan');

        return redirect()->route('admin.tujuansosial.index', $data);
    }

    public function kategoristore(Request $request)
    {
        //
        $data = $request->except('_token');
        $data['user_id'] = auth()->user()->id;
        $tujuansosialkategori = $this->tujuansosialkategoriRepo->store($data);

        $data = [
            'tujuansosialkategori' => $tujuansosialkategori->id,
        ];

        Alert::success('Berhasil', 'Kategori Tujuan Sosial berhasil disimpan');

        return redirect()->route('admin.tujuan.kategori', $data);
    }


    public function show($id)
    {
        //
    }


    public function edit($id)
    {
        //
        $menu = 'tujuansosial';
        $tujuansosial = $this->tujuansosialRepo->findId(null, $id);

        $data = [

            'menu' => $menu,
            'tujuansosial' => $tujuansosial,
        ];

        return view('admin.tujuan.edit', $data);
    }

    public function kategoriedit($id)
    {
        //
        $menu = 'tujuansosialkategori';
        $tujuansosialkategori = $this->tujuansosialkategoriRepo->findId(null, $id);

        $data = [

            'menu' => $menu,
            'tujuansosialkategori' => $tujuansosialkategori,
        ];

        return view('admin.tujuan.edit', $data);
    }


    public function update(Request $request, $id)
    {
        //
        $data = $request->except('_token');
        $data['userid_updated'] = auth()->user()->id;
        $tujuansosial = $this->tujuansosialRepo->findId(null, $id);
        $this->tujuansosialRepo->update($data, $tujuansosial);

        $data = [
            'tujuansosial' => $tujuansosial->id,
        ];

        Alert::success('Berhasil', 'tujuansosial berhasil diupdated');

        return redirect()->route('tujuansosial.index', $data);
    }

    public function tujuanupdate(Request $request, $id)
    {
        //
        $data = $request->except('_token');
        $data['userid_updated'] = auth()->user()->id;
        $tujuansosialkategori = $this->tujuansosialkategoriRepo->findId(null, $id);
        $this->tujuansosialkategoriRepo->update($data, $tujuansosialkategori);

        $data = [
            'tujuansosialkategori' => $tujuansosialkategori->id,
        ];

        Alert::success('Berhasil', 'tujuansosialkategori berhasil diupdated');

        return redirect()->route('tujuansosial.index', $data);
    }


    public function destroy($id)
    {
        //
        $model = $this->tujuansosialRepo->findId(null, Crypt::decrypt($id));
        $this->tujuansosialRepo->destroy($model);

        Alert::success('Data berhasil dihapus')->persistent('Ok');

        return redirect()->route('tujuansosial.index');
    }
}
